pub enum BaseSchemasError {
Tool(GitToolError),
Git(BaseError),
Submitted(ExecuteError),
}Expand description
Failure while assembling current and base-revision package schemas.
Variants
Tool(GitToolError)
The Git executable could not be started.
Git(BaseError)
Git could not resolve or read the requested base.
Submitted(ExecuteError)
The current checked-in schema did not satisfy the existing filesystem guard.